@@ -18,7 +18,7 @@ import javabridge
 import logging
 import os
 import sys
-import getopt
+import argparse
 import weka.core.jvm as jvm
 import weka.core.utils as utils
 from weka.core.classes import OptionHandler
@@ -149,48 +149,31 @@ class DataGenerator(OptionHandler):
             generator.jobject, args)
 
 
-def main(args):
+def main():
     """
     Runs a datagenerator from the command-line. Calls JVM start/stop automatically.
-    Options:
-        [-j jar1[:jar2...]]
-        [-X max heap size]
-        -o output
-        [-S seed]
-        [-r relation]
-        datagenerator classname
-        [datagenerator options]
+    Use -h to see all options.
     """
-
-    usage = "Usage: weka.datagenerators [-j jar1[" + os.pathsep + "jar2...]] [-X max heap size] " \
-            + "datagenerator classname -o output [-S seed] [-r relation] [datagenerator options]"
-
-    optlist, optargs = getopt.getopt(args, "j:X:h")
-    if len(optargs) == 0:
-        raise Exception("No datagenerator classname provided!\n" + usage)
-    for opt in optlist:
-        if opt[0] == "-h":
-            print(usage)
-            return
-
+    parser = argparse.ArgumentParser(
+        description='Executes a data generator from the command-line. Calls JVM start/stop automatically.')
+    parser.add_argument("-j", metavar="classpath", dest="classpath", help="additional classpath, jars/directories")
+    parser.add_argument("-X", metavar="heap", dest="heap", help="max heap size for jvm, e.g., 512m")
+    parser.add_argument("datagenerator", help="data generator classname, e.g., weka.datagenerators.classifiers.classification.LED24")
+    parser.add_argument("option", nargs=argparse.REMAINDER, help="additional data generator options")
+    parsed = parser.parse_args()
     jars = []
-    heap = None
-    for opt in optlist:
-        if opt[0] == "-j":
-            jars = opt[1].split(os.pathsep)
-        elif opt[0] == "-X":
-            heap = opt[1]
+    if not parsed.classpath is None:
+        jars = parsed.classpath.split(os.pathsep)
 
-    jvm.start(jars, max_heap_size=heap, packages=True)
+    jvm.start(jars, max_heap_size=parsed.heap, packages=True)
 
-    logger.debug("Commandline: " + utils.join_options(args))
+    logger.debug("Commandline: " + utils.join_options(sys.argv[1:]))
 
     try:
-        generator = DataGenerator(classname=optargs[0])
-        optargs = optargs[1:]
-        if len(optargs) > 0:
-            generator.set_options(optargs)
-        DataGenerator.make_data(generator, optargs)
+        generator = DataGenerator(classname=parsed.datagenerator)
+        if len(parsed.option) > 0:
+            generator.set_options(parsed.option)
+        DataGenerator.make_data(generator, parsed.option)
     except Exception, e:
         print(e)
     finally:
@@ -198,6 +181,6 @@ def main(args):
 
 if __name__ == "__main__":
     try:
-        main(sys.argv[1:])
+        main()
     except Exception, ex:
         print(ex)
